"""Information Asset Register URL Configuration

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/2.0/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  path('', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  path('', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.urls import include, path
    2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
"""
from django.conf import settings
from django.contrib import admin
from django.http import HttpResponse
from django.urls import path, include, re_path
from drf_yasg import openapi
from drf_yasg.views import get_schema_view
from rest_framework import permissions

import automationcommon.views

# Django debug toolbar is only installed in developer builds
try:
    import debug_toolbar
    HAVE_DDT = True
except ImportError:
    HAVE_DDT = False

schema_view = get_schema_view(
   openapi.Info(
      title='Information Asset Register',
      default_version='v1',
      description='Information Asset Register API',
      contact=openapi.Contact(email='devops@uis.cam.ac.uk'),
      license=openapi.License(name='MIT License'),
   ),
   public=True,
   permission_classes=(permissions.AllowAny,),
)

urlpatterns = [
    path('admin/', admin.site.urls),
    path('status', automationcommon.views.status, name='status'),
    path('accounts/', include('django.contrib.auth.urls')),
    path('accounts/', include('social_django.urls', namespace='social')),
    # use `healthy` rather than `healthz` as Cloud Run reserves the use of the `/healthz` endpoint
    path('healthy', lambda request: HttpResponse('ok', content_type="text/plain"), name='healthy'),
    path('', include('ui.urls', namespace='ui')),

    # institution lookup extension
    path('api/lookup/', include('lookupapi.urls', namespace='lookupapi')),

    # API
    path('api/tokens/', include('apitokens.urls', namespace='apitokens')),
    path('api/', include('api.urls', namespace='api')),
    # API documentation
    re_path(
        r'^api/swagger(?P<format>\.json|\.yaml)$',
        schema_view.without_ui(cache_timeout=None), name='schema-json'),
]

# In debug mode, render API UI at /api/ui
if settings.DEBUG:
    urlpatterns.append(
        path(
            'api/ui', schema_view.with_ui('swagger', cache_timeout=None),
            name='swagger-schema-ui'
        )
    )

# Selectively enable django debug toolbar URLs. Only if the toolbar is
# installed *and* DEBUG is True.
if HAVE_DDT and settings.DEBUG:
    urlpatterns = [
        path(r'__debug__/', include(debug_toolbar.urls)),
    ] + urlpatterns
